@@ -3,7 +3,7 @@ statistical<-function()
 {
 cat("\n")
   file.menu <- c("Step 2-1: Data Analysis for a Single Batch",
-                 "Step 2-2: Data Analysis for multiple Batches",
+                 "Step 2-2: Data Analysis for Multiple Batches",
                  "Back to upper level",
                  "Back to Stability menu",
                  "Quit")
